@@ -1,4 +1,4 @@
-__version__ = '0.0.2'
+__version__ = '0.0.4'
 
 import sys
 import requests
@@ -134,6 +134,8 @@ class HistoryDF:
         Args:
             t_start: a float (timestamp), a string or a datetime object
         """
+        if isinstance(t_end, datetime):
+            t_end = t_end.timestamp()
         self.params['t_end'] = t_end
         return self
 
@@ -384,8 +386,8 @@ class HistoryDF:
         return df
 
 
-def _history_df(self):
-    return HistoryDF(self)
+def _history_df(self, params_csv=None):
+    return HistoryDF(self, params_csv=params_csv)
 
 
 HttpClient.history_df = _history_df
